# God Mode

Python 3 script to easy encrypt/decrypt files.

### Usage:
```
(in development)
usage: crypt2 [-h] [-v] [-F FILES] -d DESTINATION -m {encrypt,decrypt} -p PASSWORD [-b BUFFER_MULTIPLIER] [-k] -e
                 EXTENSION [--decryptor-file DECRYPTOR_FILE]
                 [argFiles [argFiles ...]]
                 
(same as crypt2)(in development)
usage: god-mode [-h] [-v] [-f FILES] -d DESTINATION -m {encrypt,decrypt} -p PASSWORD [-b BUFFER_MULTIPLIER] [-k] -e
                 EXTENSION [--decryptor-file DECRYPTOR_FILE]
                 [argFiles [argFiles ...]]
                 
(old version)(sometimes unstable)
usage: crypt [-h] [-v] [-f FILES] -d DESTINATION -m {encrypt,decrypt} -p PASSWORD [-b BUFFER_MULTIPLIER] [-k] -e
                 EXTENSION [--decryptor-file DECRYPTOR_FILE]
                 [argFiles [argFiles ...]]
```
